@@ -5,6 +5,7 @@ import os
 import re
 import shutil
 from datetime import datetime
+from logging import DEBUG
 from pathlib import Path, PurePosixPath
 from subprocess import Popen, PIPE, STDOUT
 
@@ -22,7 +23,7 @@ logger = logging.getLogger(__name__)
 
 class FollowLog:
     BATCH_RENDER_NAME = re.compile(r'Batch render job being rendered:(.*)')
-    COMPLETE = re.compile(r'Scene .* completed')
+    COMPLETE = re.compile(r'Job Complete - Results in')
 
     def __init__(self, workdir: Path, extension: str):
         self.buffer = []
@@ -156,12 +157,11 @@ def record_time(f):
         finally:
             end = datetime.now()
             logger.info(f"Finished: {format_date(end)}")
-            logger.info(f"Took: {str(begin - end).split('.')[0]}")
+            logger.info(f"Took: {str(end - begin).split('.')[0]}")
 
     return wrapper
 
 
-@record_time
 def _run(scene):
     s3 = aws.S3(
         os.environ['AWS_BUCKET'],
@@ -170,7 +170,8 @@ def _run(scene):
         endpoint_url=os.environ['AWS_ENDPOINT'],
     )
     render = Render(PurePosixPath(scene), client=s3)
-    configure_logger(render.workdir)  # should be before run
+    # should be before run
+    configure_logger(render.workdir, level=logging.getLevelName(DEBUG))
     rc = record_time(render.run)()
     if rc > 0:
         raise Exception(f"3dsmax returned non zero code {rc}")
