@@ -1,7 +1,6 @@
 import logging
 import os
 from logging.config import dictConfig
-from pathlib import Path
 
 logging.getLogger("requests").setLevel(logging.WARNING)
 logging.getLogger("urllib3").setLevel(logging.WARNING)
@@ -10,9 +9,10 @@ logging.getLogger("pydriller").setLevel(logging.WARNING)
 logging.getLogger("amqp").setLevel(logging.WARNING)
 logging.getLogger("botocore").setLevel(logging.WARNING)
 logging.getLogger("boto3").setLevel(logging.WARNING)
+logging.getLogger("s3transfer").setLevel(logging.WARNING)
 
 
-def configure_logger(log_dir):
+def configure_logger(log_dir, level="DEBUG"):
     """Logger configuration"""
 
     os.makedirs(log_dir, exist_ok=True)
@@ -27,12 +27,12 @@ def configure_logger(log_dir):
         },
         'handlers': {
             'console': {
-                'level': 'DEBUG',
+                'level': level,
                 'formatter': 'standard',
                 'class': 'logging.StreamHandler',
             },
             'file': {
-                'level': 'DEBUG',
+                'level': level,
                 'formatter': 'standard',
                 'class': 'logging.FileHandler',
                 'filename': log_dir / 'app.log'
@@ -41,7 +41,7 @@ def configure_logger(log_dir):
         'loggers': {
             '': {
                 'handlers': ['console', 'file'],
-                'level': 'DEBUG',
+                'level': level,
                 'propagate': True
             }
         }
